@@ -164,11 +164,13 @@ class mongodb(object):
     def __contains__(self, _id):
         return bool(self[_id])
 
-    def get_order(self, params):
+    def get_params(self, params):
         if type(params) is str:
             desc = params[0] == '!'
             key  = params.strip("!")
             return {"order" : key, "desc" : desc}
+        if type(params) is dict:
+            return params
         return {"order" : "_id", "desc" : params == -1}
 
     def __getitem__(self, _id):
@@ -178,7 +180,7 @@ class mongodb(object):
             log("分片操作， [{}:{}:{}]".format(_id.start, _id.stop, _id.step), level=self.level)
             offset = _id.start or 0
             limit  = (_id.stop or 0) - offset
-            kwargs = self.get_order(_id.step)
+            kwargs = self.get_params(_id.step)
             return self.get(offset=offset, limit=limit, **kwargs)
 
         data = self._table.find({"_id":_id})
